@@ -9,8 +9,8 @@ var indexSectionsWithContent =
   6: "abcdefghiklmnoprstuv",
   7: "abcdefghilmnoprstuvwxz",
   8: "abcdefghijklmnopqrstuvwxyz",
-  9: "_",
-  10: "dt"
+  9: "_cio",
+  10: "dlt"
 };
 
 var indexSectionNames =
